import { useState, useEffect } from 'react';
import { throttle } from 'lodash';

export default function useContainerPadding({
  imageSizeOptions, breakpoint,
}) {
  const [containerPadding, setContainerPadding] = useState(66.66);
  // default 3:2 aspect ratio

  const {
    width: intrinsicWidth,
    height: intrinsicHeight,
    mobileWidth: mobileIntrinsicWidth,
    mobileHeight: mobileIntrinsicHeight,
    aspectRatio: givenAspectRatio,
    mobileAspectRatio: givenMobileAspectRatio,
  } = imageSizeOptions;

  const aspectRatio = givenAspectRatio || intrinsicHeight / intrinsicWidth;
  const mobileAspectRatio = givenMobileAspectRatio
  || mobileIntrinsicHeight / mobileIntrinsicWidth;

  const changeContainerPadding = throttle(() => {
    const windowWidth = window.innerWidth;
    if (windowWidth < breakpoint) {
      setContainerPadding(mobileAspectRatio * 100);
    } else {
      setContainerPadding(aspectRatio * 100);
    }
  }, 500);

  useEffect(() => {
    changeContainerPadding();

    window.addEventListener('resize', changeContainerPadding);

    return () => window.removeEventListener('resize', changeContainerPadding);
  }, []);

  return containerPadding;
}
