import { useRef, useState, useEffect } from 'react';

export default function useIsObserved({ observationThreshold, rootMargin }) {
  const self = useRef();
  const [observed, setObserved] = useState(false);

  useEffect(() => {
    if (!observed) {
      const options = {
        rootMargin,
        threshold: 0,
      };

      const cb = (entries) => {
        const entry = entries[0];
        if (entry.isIntersecting) {
          setObserved(true);
        }
      };

      const observer = new window.IntersectionObserver(cb, options);

      if (self.current) {
        observer.observe(self.current);
      }

      return () => {
        observer.disconnect();
      };
    }

    return () => {};
  }, [observed, observationThreshold, self.current]);

  return [self, observed];
}
