import PropTypes from 'prop-types';
import classnames from 'classnames';
import Caption from './Caption';
import baseClasses from './styles.module.scss';
import Image from './Image';

const PoliticoImage = function PoliticoImage(props) {
  const
    {
      src,
      mobileSrc,
      alt,
      width,
      height,
      aspectRatio,
      mobileWidth,
      mobileHeight,
      mobileAspectRatio,
      quality,
      breakpoint,
      classes,
      caption,
      credit,
      rootMargin,
      styled,
    } = props;

  const {
    caption: captionClass,
    figure: figureClass,
  } = classes;

  const imageSizeOptions = {
    width,
    height,
    mobileWidth,
    mobileHeight,
    aspectRatio,
    mobileAspectRatio,
  };
  return (
    <figure className={classnames(baseClasses.figure, figureClass)}>
      <Image
        src={src}
        mobileSrc={mobileSrc}
        alt={alt}
        rootMargin={rootMargin}
        quality={quality}
        imageSizeOptions={imageSizeOptions}
        breakpoint={breakpoint}
      />
      <Caption
        caption={caption}
        credit={credit}
        className={captionClass}
        styled={styled}
      />
    </figure>

  );
};

PoliticoImage.defaultProps = {
  src: PropTypes.string.isRequired,
  alt: PropTypes.string.isRequired,
  width: PropTypes.number,
  height: PropTypes.number,
  aspectRatio: PropTypes.number,
  mobileWidth: PropTypes.number,
  mobileHeight: PropTypes.number,
  mobileAspectRatio: PropTypes.number,
  quality: PropTypes.number,
  breakpoint: PropTypes.number,
  classes: PropTypes.shape({
    figure: PropTypes.string,
    caption: PropTypes.string,
  }),
  caption: PropTypes.string,
  credit: PropTypes.string,
  rootMargin: PropTypes.number,
  styled: PropTypes.bool,

};

PoliticoImage.defaultProps = {
  aspectRatio: 0.66,
  quality: 75,
  breakpoint: 768,
  rootMargin: '500px',
};

export default PoliticoImage;
