import Template from './_advancedTemplate';
import ContentComponent from './_common/ContentComponent';

const AdvancedTooltipSharedComponentType = Template.bind({});

AdvancedTooltipSharedComponentType.args = {
  useTooltipOptions: {
    content: ContentComponent,
  },
  triggerProps: [
    { props: { text: 'Hello from Tooltip 1!' } },
    { props: { text: 'Hello from Tooltip 2!' } },
    { props: { text: 'Hello from Tooltip 3!' } },
  ],
};

AdvancedTooltipSharedComponentType.parameters = {
  docs: {
    description: {
      story: `
Here we are using the \`useTooltip\` hook to coordinate our own
\`TooltipDisplay\` and \`TooltipTrigger\` components. We pass a component type
as the \`content\` key of the \`useTooltip\` options argument, which means
that, by default, one instance of that component type will be rendered to
create the tooltip contents for each trigger. We pass the \`TooltipTrigger\`
components a prop called \`props\`, which specifies the props with which to
render our tooltip contents component when that specific trigger is
activated.

In this example, \`MyTooltipContentComponent\` is a component type that renders
a styled \`div\` around whatever is specified as its \`text\` prop, so for each
\`TooltipTrigger\` we get the samed styled \`div\` around different text each
time.
`,
    },
    source: {
      code: `
import { useTooltip, TooltipDisplay, TooltipTrigger } from '@politico/interactive-style';
import MyTooltipContentComponent from './MyTooltipContentComponent';

const MyParentComponent = function MyParentComponent(props) {
  const tooltip = useTooltip({
    content: MyTooltipContentComponent,
  });

  return (
    <div>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 1!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 2!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 3!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipDisplay tooltip={tooltip} />
    </div>
  );
};

export default MyParentComponent;
`,
    },
  },
};

export default AdvancedTooltipSharedComponentType;
